==> gnuastro_0.7.orig.tar.gz: gnuastro-0.7/tests/match/merged-cols.sh <==
# Match the two input catalogs and return merged output
#
# See the Tests subsection of the manual for a complete explanation
# (in the Installing gnuastro section).
#
# Original author:
#     Mohammad Akhlaghi <mohammad@akhlaghi.org>
# Contributing author(s):
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without any warranty.





# Preliminaries
# =============
#
# Set the variables (The executable is in the build tree). Do the
# basic checks to see if the executable is made or if the defaults
# file exists (basicchecks.sh is in the source tree).
prog=match
execname=../bin/$prog/ast$prog
cat1=$topsrc/tests/$prog/positions-1.txt
cat2=$topsrc/tests/$prog/positions-2.txt





# Skip?
# =====
#
# If the dependencies of the test don't exist, then skip it. There are two
# types of dependencies:
#
#   - The executable was not made (for example due to a configure option),
#
#   - The input data was not made (for example the test that created the
#     data file failed).
if [ ! -f $execname ]; then echo "$execname not created."; exit 77; fi





# Actual test script
# ==================
#
# `check_with_program' can be something like `Valgrind' or an empty
# string. Such programs will execute the command if present and help in
# debugging when the developer doesn't have access to the user's system.
$check_with_program $execname $cat1 $cat2 --aperture=0.5             \
                              -omatch-merged-cols.txt                \
                              --outcols=a1,aEFGH,bACCU1,aIJKL,bACCU2

==> gnuastro-0.11.tar.gz: gnuastro-0.11/tests/match/merged-cols.sh <==
# Match the two input catalogs and return merged output
#
# See the Tests subsection of the manual for a complete explanation
# (in the Installing gnuastro section).
#
# Original author:
#     Mohammad Akhlaghi <mohammad@akhlaghi.org>
# Contributing author(s):
# Copyright (C) 2015-2019 Free Software Foundation, Inc.
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without any warranty.





# Preliminaries
# =============
#
# Set the variables (The executable is in the build tree). Do the
# basic checks to see if the executable is made or if the defaults
# file exists (basicchecks.sh is in the source tree).
prog=match
execname=../bin/$prog/ast$prog
cat1=$topsrc/tests/$prog/positions-1.txt
cat2=$topsrc/tests/$prog/positions-2.txt





# Skip?
# =====
#
# If the dependencies of the test don't exist, then skip it. There are two
# types of dependencies:
#
#   - The executable was not made (for example due to a configure option),
#
#   - The input data was not made (for example the test that created the
#     data file failed).
if [ ! -f $execname ]; then echo "$execname not created."; exit 77; fi





# Actual test script
# ==================
#
# `check_with_program' can be something like `Valgrind' or an empty
# string. Such programs will execute the command if present and help in
# debugging when the developer doesn't have access to the user's system.
$check_with_program $execname $cat1 $cat2 --aperture=0.5 --ccol1=2,3   \
                               --ccol2=2,3 -omatch-merged-cols.txt     \
                              --outcols=a1,aEFGH,bACCU1,aIJKL,bACCU2
